@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,9 @@ import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.aiplatform.v1.schema.predict.params",
-    manifest={"ImageSegmentationPredictionParams",},
+    manifest={
+        "ImageSegmentationPredictionParams",
+    },
 )
 
 
@@ -34,7 +36,10 @@ class ImageSegmentationPredictionParams(proto.Message):
             background. Default value is 0.5.
     """
 
-    confidence_threshold = proto.Field(proto.FLOAT, number=1,)
+    confidence_threshold = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
