@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,9 @@ import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.aiplatform.v1.schema.predict.prediction",
-    manifest={"TabularClassificationPredictionResult",},
+    manifest={
+        "TabularClassificationPredictionResult",
+    },
 )
 
 
@@ -37,8 +39,14 @@ class TabularClassificationPredictionResult(proto.Message):
             classes.
     """
 
-    classes = proto.RepeatedField(proto.STRING, number=1,)
-    scores = proto.RepeatedField(proto.FLOAT, number=2,)
+    classes = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    scores = proto.RepeatedField(
+        proto.FLOAT,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
