@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -237,6 +237,35 @@ class DatasetServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a Dataset.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_create_dataset():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                dataset = aiplatform_v1.Dataset()
+                dataset.display_name = "display_name_value"
+                dataset.metadata_schema_uri = "metadata_schema_uri_value"
+                dataset.metadata.null_value = "NULL_VALUE"
+
+                request = aiplatform_v1.CreateDatasetRequest(
+                    parent="parent_value",
+                    dataset=dataset,
+                )
+
+                # Make the request
+                operation = client.create_dataset(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.CreateDatasetRequest, dict]):
                 The request object. Request message for
@@ -303,7 +332,12 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -327,6 +361,25 @@ class DatasetServiceAsyncClient:
     ) -> dataset.Dataset:
         r"""Gets a Dataset.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_get_dataset():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.GetDatasetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_dataset(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.GetDatasetRequest, dict]):
                 The request object. Request message for
@@ -382,7 +435,12 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -399,6 +457,30 @@ class DatasetServiceAsyncClient:
     ) -> gca_dataset.Dataset:
         r"""Updates a Dataset.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_update_dataset():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                dataset = aiplatform_v1.Dataset()
+                dataset.display_name = "display_name_value"
+                dataset.metadata_schema_uri = "metadata_schema_uri_value"
+                dataset.metadata.null_value = "NULL_VALUE"
+
+                request = aiplatform_v1.UpdateDatasetRequest(
+                    dataset=dataset,
+                )
+
+                # Make the request
+                response = client.update_dataset(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.UpdateDatasetRequest, dict]):
                 The request object. Request message for
@@ -471,7 +553,12 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -487,6 +574,26 @@ class DatasetServiceAsyncClient:
     ) -> pagers.ListDatasetsAsyncPager:
         r"""Lists Datasets in a Location.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_list_datasets():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListDatasetsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_datasets(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListDatasetsRequest, dict]):
                 The request object. Request message for
@@ -545,12 +652,20 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListDatasetsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -567,6 +682,29 @@ class DatasetServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a Dataset.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_delete_dataset():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.DeleteDatasetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_dataset(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.DeleteDatasetRequest, dict]):
                 The request object. Request message for
@@ -636,7 +774,12 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -661,6 +804,34 @@ class DatasetServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Imports data into a Dataset.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_import_data():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                import_configs = aiplatform_v1.ImportDataConfig()
+                import_configs.gcs_source.uris = ['uris_value_1', 'uris_value_2']
+                import_configs.import_schema_uri = "import_schema_uri_value"
+
+                request = aiplatform_v1.ImportDataRequest(
+                    name="name_value",
+                    import_configs=import_configs,
+                )
+
+                # Make the request
+                operation = client.import_data(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ImportDataRequest, dict]):
                 The request object. Request message for
@@ -730,7 +901,12 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -755,6 +931,33 @@ class DatasetServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Exports data from a Dataset.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_export_data():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                export_config = aiplatform_v1.ExportDataConfig()
+                export_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
+
+                request = aiplatform_v1.ExportDataRequest(
+                    name="name_value",
+                    export_config=export_config,
+                )
+
+                # Make the request
+                operation = client.export_data(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ExportDataRequest, dict]):
                 The request object. Request message for
@@ -823,7 +1026,12 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -847,6 +1055,26 @@ class DatasetServiceAsyncClient:
     ) -> pagers.ListDataItemsAsyncPager:
         r"""Lists DataItems in a Dataset.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_list_data_items():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListDataItemsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_data_items(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListDataItemsRequest, dict]):
                 The request object. Request message for
@@ -906,12 +1134,20 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListDataItemsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -928,6 +1164,25 @@ class DatasetServiceAsyncClient:
     ) -> annotation_spec.AnnotationSpec:
         r"""Gets an AnnotationSpec.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_get_annotation_spec():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.GetAnnotationSpecRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_annotation_spec(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.GetAnnotationSpecRequest, dict]):
                 The request object. Request message for
@@ -984,7 +1239,12 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1000,6 +1260,26 @@ class DatasetServiceAsyncClient:
     ) -> pagers.ListAnnotationsAsyncPager:
         r"""Lists Annotations belongs to a dataitem
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_list_annotations():
+                # Create a client
+                client = aiplatform_v1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListAnnotationsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_annotations(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListAnnotationsRequest, dict]):
                 The request object. Request message for
@@ -1059,12 +1339,20 @@ class DatasetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListAnnotationsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
