@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -43,6 +43,9 @@ from google.cloud.aiplatform_v1beta1.types import explanation
 from google.cloud.aiplatform_v1beta1.types import model
 from google.cloud.aiplatform_v1beta1.types import model as gca_model
 from google.cloud.aiplatform_v1beta1.types import model_evaluation
+from google.cloud.aiplatform_v1beta1.types import (
+    model_evaluation as gca_model_evaluation,
+)
 from google.cloud.aiplatform_v1beta1.types import model_evaluation_slice
 from google.cloud.aiplatform_v1beta1.types import model_service
 from google.cloud.aiplatform_v1beta1.types import operation as gca_operation
@@ -67,7 +70,10 @@ class ModelServiceClientMeta(type):
     _transport_registry["grpc"] = ModelServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = ModelServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[ModelServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[ModelServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -172,10 +178,16 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def endpoint_path(project: str, location: str, endpoint: str,) -> str:
+    def endpoint_path(
+        project: str,
+        location: str,
+        endpoint: str,
+    ) -> str:
         """Returns a fully-qualified endpoint string."""
         return "projects/{project}/locations/{location}/endpoints/{endpoint}".format(
-            project=project, location=location, endpoint=endpoint,
+            project=project,
+            location=location,
+            endpoint=endpoint,
         )
 
     @staticmethod
@@ -188,10 +200,16 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def model_path(project: str, location: str, model: str,) -> str:
+    def model_path(
+        project: str,
+        location: str,
+        model: str,
+    ) -> str:
         """Returns a fully-qualified model string."""
         return "projects/{project}/locations/{location}/models/{model}".format(
-            project=project, location=location, model=model,
+            project=project,
+            location=location,
+            model=model,
         )
 
     @staticmethod
@@ -205,11 +223,17 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
 
     @staticmethod
     def model_evaluation_path(
-        project: str, location: str, model: str, evaluation: str,
+        project: str,
+        location: str,
+        model: str,
+        evaluation: str,
     ) -> str:
         """Returns a fully-qualified model_evaluation string."""
         return "projects/{project}/locations/{location}/models/{model}/evaluations/{evaluation}".format(
-            project=project, location=location, model=model, evaluation=evaluation,
+            project=project,
+            location=location,
+            model=model,
+            evaluation=evaluation,
         )
 
     @staticmethod
@@ -223,7 +247,11 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
 
     @staticmethod
     def model_evaluation_slice_path(
-        project: str, location: str, model: str, evaluation: str, slice: str,
+        project: str,
+        location: str,
+        model: str,
+        evaluation: str,
+        slice: str,
     ) -> str:
         """Returns a fully-qualified model_evaluation_slice string."""
         return "projects/{project}/locations/{location}/models/{model}/evaluations/{evaluation}/slices/{slice}".format(
@@ -245,11 +273,15 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
 
     @staticmethod
     def training_pipeline_path(
-        project: str, location: str, training_pipeline: str,
+        project: str,
+        location: str,
+        training_pipeline: str,
     ) -> str:
         """Returns a fully-qualified training_pipeline string."""
         return "projects/{project}/locations/{location}/trainingPipelines/{training_pipeline}".format(
-            project=project, location=location, training_pipeline=training_pipeline,
+            project=project,
+            location=location,
+            training_pipeline=training_pipeline,
         )
 
     @staticmethod
@@ -262,7 +294,9 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -275,9 +309,13 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -286,9 +324,13 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -297,9 +339,13 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -308,10 +354,14 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -497,6 +547,33 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Uploads a Model artifact into Vertex AI.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_upload_model():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                model = aiplatform_v1beta1.Model()
+                model.display_name = "display_name_value"
+
+                request = aiplatform_v1beta1.UploadModelRequest(
+                    parent="parent_value",
+                    model=model,
+                )
+
+                # Make the request
+                operation = client.upload_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.UploadModelRequest, dict]):
                 The request object. Request message for
@@ -565,7 +642,12 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -589,6 +671,25 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
     ) -> model.Model:
         r"""Gets a Model.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_model():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetModelRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_model(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetModelRequest, dict]):
                 The request object. Request message for
@@ -642,7 +743,12 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -658,6 +764,26 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
     ) -> pagers.ListModelsPager:
         r"""Lists Models in a Location.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_models():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListModelsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_models(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListModelsRequest, dict]):
                 The request object. Request message for
@@ -717,12 +843,20 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListModelsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -740,6 +874,28 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
     ) -> gca_model.Model:
         r"""Updates a Model.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_update_model():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                model = aiplatform_v1beta1.Model()
+                model.display_name = "display_name_value"
+
+                request = aiplatform_v1beta1.UpdateModelRequest(
+                    model=model,
+                )
+
+                # Make the request
+                response = client.update_model(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.UpdateModelRequest, dict]):
                 The request object. Request message for
@@ -805,7 +961,12 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -829,6 +990,30 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         [deployed_models][google.cloud.aiplatform.v1beta1.Endpoint.deployed_models]
         field.
 
+
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_delete_model():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.DeleteModelRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeleteModelRequest, dict]):
                 The request object. Request message for
@@ -898,7 +1083,12 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -926,6 +1116,30 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         least one [supported export
         format][google.cloud.aiplatform.v1beta1.Model.supported_export_formats].
 
+
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_export_model():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ExportModelRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.export_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ExportModelRequest, dict]):
                 The request object. Request message for
@@ -995,7 +1209,12 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -1008,6 +1227,113 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         # Done; return the response.
         return response
 
+    def import_model_evaluation(
+        self,
+        request: Union[model_service.ImportModelEvaluationRequest, dict] = None,
+        *,
+        parent: str = None,
+        model_evaluation: gca_model_evaluation.ModelEvaluation = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> gca_model_evaluation.ModelEvaluation:
+        r"""Imports an externally generated ModelEvaluation.
+
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_import_model_evaluation():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ImportModelEvaluationRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.import_model_evaluation(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.aiplatform_v1beta1.types.ImportModelEvaluationRequest, dict]):
+                The request object. Request message for
+                [ModelService.ImportModelEvaluation][google.cloud.aiplatform.v1beta1.ModelService.ImportModelEvaluation]
+            parent (str):
+                Required. The name of the parent model resource. Format:
+                ``projects/{project}/locations/{location}/models/{model}``
+
+                This corresponds to the ``parent`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            model_evaluation (google.cloud.aiplatform_v1beta1.types.ModelEvaluation):
+                Required. Model evaluation resource
+                to be imported.
+
+                This corresponds to the ``model_evaluation`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.aiplatform_v1beta1.types.ModelEvaluation:
+                A collection of metrics calculated by
+                comparing Model's predictions on all of
+                the test data against annotations from
+                the test data.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([parent, model_evaluation])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a model_service.ImportModelEvaluationRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, model_service.ImportModelEvaluationRequest):
+            request = model_service.ImportModelEvaluationRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if parent is not None:
+                request.parent = parent
+            if model_evaluation is not None:
+                request.model_evaluation = model_evaluation
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.import_model_evaluation]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def get_model_evaluation(
         self,
         request: Union[model_service.GetModelEvaluationRequest, dict] = None,
@@ -1019,6 +1345,25 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
     ) -> model_evaluation.ModelEvaluation:
         r"""Gets a ModelEvaluation.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_model_evaluation():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetModelEvaluationRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_model_evaluation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetModelEvaluationRequest, dict]):
                 The request object. Request message for
@@ -1077,7 +1422,12 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1093,6 +1443,26 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
     ) -> pagers.ListModelEvaluationsPager:
         r"""Lists ModelEvaluations in a Model.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_model_evaluations():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListModelEvaluationsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_model_evaluations(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListModelEvaluationsRequest, dict]):
                 The request object. Request message for
@@ -1152,12 +1522,20 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListModelEvaluationsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1174,6 +1552,25 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
     ) -> model_evaluation_slice.ModelEvaluationSlice:
         r"""Gets a ModelEvaluationSlice.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_model_evaluation_slice():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetModelEvaluationSliceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_model_evaluation_slice(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetModelEvaluationSliceRequest, dict]):
                 The request object. Request message for
@@ -1234,7 +1631,12 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1250,6 +1652,26 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
     ) -> pagers.ListModelEvaluationSlicesPager:
         r"""Lists ModelEvaluationSlices in a ModelEvaluation.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_model_evaluation_slices():
+                # Create a client
+                client = aiplatform_v1beta1.ModelServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListModelEvaluationSlicesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_model_evaluation_slices(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListModelEvaluationSlicesRequest, dict]):
                 The request object. Request message for
@@ -1311,12 +1733,20 @@ class ModelServiceClient(metaclass=ModelServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListModelEvaluationSlicesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
